# -*- coding: utf-8 -*-
# Copyright (c) 2010-2013 Infrae. All rights reserved.
# See also LICENSE.txt

import unittest

from infrae.testbrowser.headers import HTTPHeaders

class HeaderTestCase(unittest.TestCase):

    def test_set_and_get(self):
        """You can set and read values. This is case insensitive.
        """
        headers = HTTPHeaders()

        headers['content-type'] = 'text/plain'
        self.assertEqual(headers['content-type'], 'text/plain')
        self.assertEqual(headers['Content-Type'], 'text/plain')

        headers['Content-Type'] = 'application/octet-stream'
        self.assertEqual(headers['content-type'], 'application/octet-stream')
        self.assertEqual(headers['Content-Type'], 'application/octet-stream')

        headers.update(
            list({'Content-Type': 'text/html', 'Content-Length': '42'}.items()))
        self.assertEqual(headers['content-type'], 'text/html')
        self.assertEqual(headers['content-length'], '42')

    def test_non_existing_get(self):
        """Looking a non existing key raises KeyError.
        """
        headers = HTTPHeaders()

        self.assertRaises(KeyError, headers.__getitem__, 'Missing')
        self.assertRaises(KeyError, headers.__getitem__, 'missing')

    def test_has_key(self):
        """You can check is an header is already set. This is case
        insensitive as well.
        """
        headers = HTTPHeaders()

        headers['Content-Length'] = '42'
        self.assertEqual('Content-Length' in headers, True)
        self.assertEqual('content-length' in headers, True)
        self.assertTrue('Content-Length' in headers)
        self.assertTrue('content-length' in headers)

        self.assertEqual('Server' in headers, False)
        self.assertEqual('server' in headers, False)
        self.assertFalse('Server' in headers)
        self.assertFalse('server' in headers)

    def test_items(self):
        """items return a list of tuples containing all headers. Header
        names are normalized, and value are converted to strings.
        """
        headers = HTTPHeaders()

        headers['content-type'] = 'text/plain'
        headers['Content-length'] = 42
        self.assertEqual(
            list(headers.items()),
            [('Content-Length', '42'), ('Content-Type', 'text/plain')])
        self.assertEqual(
            list(headers.items()),
            [('Content-Length', '42'), ('Content-Type', 'text/plain')])

